@@ -25,8 +25,6 @@ from kazoo.handlers import threading as threading_handler
 from kazoo.protocol import paths
 from oslo_utils import encodeutils
 from oslo_utils import strutils
-import six
-from six.moves import filter as compat_filter
 
 import tooz
 from tooz import coordination
@@ -88,6 +86,10 @@ class KazooDriver(coordination.CoordinationDriverCachedRunWatchers):
     will be extracted from the coordinator url (or any provided options),
     so that a specific coordinator can be created that will work for you.
 
+    The Zookeeper coordinator url should look like::
+
+      zookeeper://[USERNAME:PASSWORD@][HOST[:PORT]][?OPTION1=VALUE1[&OPTION2=VALUE2[&...]]]
+
     Currently the following options will be proxied to the contained client:
 
     ================  ===============================  ====================
@@ -136,7 +138,7 @@ class KazooDriver(coordination.CoordinationDriverCachedRunWatchers):
     """
 
     def __init__(self, member_id, parsed_url, options):
-        super(KazooDriver, self).__init__(member_id)
+        super(KazooDriver, self).__init__(member_id, parsed_url, options)
         options = utils.collapse(options, exclude=['hosts'])
         self.timeout = int(options.get('timeout', '10'))
         self._namespace = options.get('namespace', self.TOOZ_NAMESPACE)
@@ -440,7 +442,7 @@ class KazooDriver(coordination.CoordinationDriverCachedRunWatchers):
         args.extend(more_args)
         cleaned_args = []
         for arg in args:
-            if isinstance(arg, six.binary_type):
+            if isinstance(arg, bytes):
                 cleaned_args.append(arg.decode('ascii'))
             else:
                 cleaned_args.append(arg)
@@ -463,7 +465,7 @@ class KazooDriver(coordination.CoordinationDriverCachedRunWatchers):
             auth_data = None
 
         maybe_hosts = [parsed_url.netloc] + list(options.get('hosts', []))
-        hosts = list(compat_filter(None, maybe_hosts))
+        hosts = list(filter(None, maybe_hosts))
         if not hosts:
             hosts = ['localhost:2181']
         randomize_hosts = options.get('randomize_hosts', True)
@@ -516,7 +518,7 @@ class KazooDriver(coordination.CoordinationDriverCachedRunWatchers):
         return ZooKeeperLock(name, z_lock)
 
     def run_elect_coordinator(self):
-        for group_id in six.iterkeys(self._hooks_elected_leader):
+        for group_id in self._hooks_elected_leader.keys():
             leader_lock = self._get_group_leader_lock(group_id)
             if leader_lock.is_acquired:
                 # Previously acquired/still leader, leave it be...
@@ -540,7 +542,7 @@ class ZooAsyncResult(coordination.CoordAsyncResult):
         self._handler = handler
         self._kwargs = kwargs
 
-    def get(self, timeout=10):
+    def get(self, timeout=None):
         return self._handler(self._kazoo_async_result, timeout, **self._kwargs)
 
     def done(self):
