@@ -15,26 +15,24 @@
 #    under the License.
 import abc
 
-import six
-
 import tooz
 from tooz import coordination
 
 
 class _LockProxy(object):
-    def __init__(self, lock, blocking=True):
+    def __init__(self, lock, *args, **kwargs):
         self.lock = lock
-        self.blocking = blocking
+        self.args = args
+        self.kwargs = kwargs
 
     def __enter__(self):
-        return self.lock.__enter__(self.blocking)
+        return self.lock.__enter__(*self.args, **self.kwargs)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.lock.__exit__(exc_type, exc_val, exc_tb)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Lock(object):
+class Lock(object, metaclass=abc.ABCMeta):
     def __init__(self, name):
         if not name:
             raise ValueError("Locks must be provided a name")
@@ -44,11 +42,11 @@ class Lock(object):
     def name(self):
         return self._name
 
-    def __call__(self, blocking=True):
-        return _LockProxy(self, blocking)
+    def __call__(self, *args, **kwargs):
+        return _LockProxy(self, *args, **kwargs)
 
-    def __enter__(self, blocking=True):
-        acquired = self.acquire(blocking)
+    def __enter__(self, *args, **kwargs):
+        acquired = self.acquire(*args, **kwargs)
         if not acquired:
             msg = u'Acquiring lock %s failed' % self.name
             raise coordination.LockAcquireFailed(msg)
@@ -79,15 +77,33 @@ class Lock(object):
         :rtype: bool
         """
 
+    def break_(self):
+        """Forcefully release the lock.
+
+        This is mostly used for testing purposes, to simulate an out of
+        band operation that breaks the lock. Backends may allow waiters to
+        acquire immediately if a lock is broken, or they should raise an
+        exception. Releasing should be successful for objects that believe
+        they hold the lock but do not have the lock anymore. However,
+        they should be careful not to re-break the lock by releasing it,
+        since they may not be the holder anymore.
+
+        :returns: returns true if forcefully broken (false if not)
+                  or raises ``NotImplemented`` if not implemented.
+        """
+        raise tooz.NotImplemented
+
     @abc.abstractmethod
-    def acquire(self, blocking=True):
+    def acquire(self, blocking=True, shared=False):
         """Attempts to acquire the lock.
 
         :param blocking: If True, blocks until the lock is acquired. If False,
                          returns right away. Otherwise, the value is used as a
                          timeout value and the call returns maximum after this
                          number of seconds.
+        :param shared: If False, the lock is exclusive. If True, the lock can
+                       be shareable or raises ``NotImplemented`` if not
+                       implemented.
         :returns: returns true if acquired (false if not)
         :rtype: bool
-
         """
